@@ -1,8 +1,9 @@
-# !/usr/bin/env python
-# This script has been developed by Mazzya
-# Github : https://github.com/Mazzya
-# Repository address : https://github.com/Mazzya/password-generator-module
+# This script has been developed by the Frit Apps Organization
+# Github: https://github.com/frit-apps
+# Repository address: https://github.com/frit-apps/password-generator-module
+# Documentation: https://password-generator-module.readthedocs.io/en/latest/
 # This is a module that allows you to generate passwords safely and quickly
+# Version 0.1.2
 
 import string
 import secrets
@@ -30,7 +31,7 @@ class Password:
                 for i in range(length): password += secrets.choice(chars)
                 return password
             else:
-                print("The password must contain at least 4 characters")
+                raise ValueError("The password must contain at least 4 characters")
         except TypeError:
             """If the user passes a non-numeric value as a parameter"""
             print("Please enter a numeric value")
